Applications — BAGO 0.0.1 documentation

# Applications

BAGO evaluate the compound separations from the following applications:

- Compound separation efficiency - Omics-scale evaluation on compound separation. Read more from Compute Separation Efficiency

- MS1 acquisition - Evaluation on unique m/z values. Read more from Get unique m/z

- MS2 acquisition - Evaluate the number of unique MS2. Read more from Get unique MS2 spectra

- Base peak chromatography - Visualization of compound separation. Read more from Plot BPC

Other metabolomics data processing tools can also be used for customized evaluation:

XCMS | MS-DIAL | MZmine 3 | El-MAVEN |